@@ -24,11 +24,12 @@ class ProviderSwitchHandler(object):
         self.retry_when_not_found = kwargs.get('retry_when_not_found', False)
         self.providers = []
         self.current_provider = None
+        self.driver_type = kwargs.get('driver_type', 'sms')
         self._prepare()
 
     def _prepare(self) -> None:
         providers = ProviderCollection(
-            driver_type='ssm', social_type=self.social_type, service_name=self.service_name,
+            driver_type=self.driver_type, social_type=self.social_type, service_name=self.service_name,
             retry_when_not_found=self.retry_when_not_found).get_providers()
         if self.allowed_providers is not None:
             providers = [provider for provider in providers if provider.name in self.allowed_providers]
@@ -142,7 +143,8 @@ class ProviderSwitchHandler(object):
 
         self.current_provider.increment_session_success()
         try:
-            self.current_provider.sync(provider_data)
+            print('Sync parameter')
+            # self.current_provider.sync(provider_data)
         except Exception as e:
             print(f'Error sync parameter: {str(e)}')
 
